@@ -104,7 +104,9 @@ struct _PhotosApplication
   PhotosSearchProvider *search_provider;
   PhotosSelectionController *sel_cntrlr;
   TrackerExtractPriority *extract_priority;
+  gboolean main_window_deleted;
   guint create_miners_count;
+  guint use_count;
   guint32 activation_timestamp;
   gulong source_added_id;
   gulong source_removed_id;
@@ -139,6 +141,12 @@ enum
   MINER_REFRESH_TIMEOUT = 60 /* s */
 };
 
+static const GOptionEntry COMMAND_LINE_OPTIONS[] =
+{
+  { "version", 0, G_OPTION_FLAG_NONE, G_OPTION_ARG_NONE, NULL, N_("Show the application's version"), NULL},
+  { NULL }
+};
+
 static const gchar *REQUIRED_GEGL_OPS[] =
 {
   "gegl:buffer-sink",
@@ -414,6 +422,20 @@ photos_application_tracker_clear_rdf_types (GObject *source_object, GAsyncResult
 }
 
 
+static gboolean
+photos_application_delete_event (PhotosApplication *self)
+{
+  gboolean ret_val = GDK_EVENT_PROPAGATE;
+
+  self->main_window_deleted = TRUE;
+
+  if (self->use_count > 0)
+    ret_val = gtk_widget_hide_on_delete (self->main_window);
+
+  return ret_val;
+}
+
+
 static void
 photos_application_destroy (PhotosApplication *self)
 {
@@ -609,8 +631,15 @@ photos_application_create_window (PhotosApplication *self)
   g_return_val_if_fail (photos_application_sanity_check_gegl (self), FALSE);
 
   self->main_window = photos_main_window_new (GTK_APPLICATION (self));
+  g_signal_connect_object (self->main_window,
+                           "delete-event",
+                           G_CALLBACK (photos_application_delete_event),
+                           self,
+                           G_CONNECT_AFTER | G_CONNECT_SWAPPED);
   g_signal_connect_swapped (self->main_window, "destroy", G_CALLBACK (photos_application_destroy), self);
 
+  self->main_window_deleted = FALSE;
+
   g_application_hold (G_APPLICATION (self));
   tracker_extract_priority_proxy_new_for_bus (G_BUS_TYPE_SESSION,
                                               G_DBUS_PROXY_FLAGS_NONE,
@@ -1312,6 +1341,21 @@ photos_application_dbus_unregister (GApplication *application,
 }
 
 
+static gint
+photos_application_handle_local_options (GApplication *application, GVariantDict *options)
+{
+  gint ret_val = -1;
+
+  if (g_variant_dict_contains (options, "version"))
+    {
+      g_print ("%s %s\n", PACKAGE_TARNAME, PACKAGE_VERSION);
+      ret_val = 0;
+    }
+
+  return ret_val;
+}
+
+
 static void
 photos_application_shutdown (GApplication *application)
 {
@@ -1647,7 +1691,7 @@ photos_application_finalize (GObject *object)
 
   g_assert (self->create_miners_count == 0);
 
-  if (!g_application_get_is_remote (G_APPLICATION (self)))
+  if (g_application_get_is_registered (G_APPLICATION (self)) && !g_application_get_is_remote (G_APPLICATION (self)))
     gegl_exit ();
 
   G_OBJECT_CLASS (photos_application_parent_class)->finalize (object);
@@ -1671,6 +1715,8 @@ photos_application_init (PhotosApplication *self)
 
   self->state = photos_search_context_state_new (PHOTOS_SEARCH_CONTEXT (self));
   self->activation_timestamp = GDK_CURRENT_TIME;
+
+  g_application_add_main_option_entries (G_APPLICATION (self), COMMAND_LINE_OPTIONS);
 }
 
 
@@ -1685,6 +1731,7 @@ photos_application_class_init (PhotosApplicationClass *class)
   application_class->activate = photos_application_activate;
   application_class->dbus_register = photos_application_dbus_register;
   application_class->dbus_unregister = photos_application_dbus_unregister;
+  application_class->handle_local_options = photos_application_handle_local_options;
   application_class->shutdown = photos_application_shutdown;
   application_class->startup = photos_application_startup;
 
@@ -1743,3 +1790,23 @@ photos_application_get_scale_factor (PhotosApplication *self)
  out:
   return ret_val;
 }
+
+
+void
+photos_application_hold (PhotosApplication *self)
+{
+  g_return_if_fail (PHOTOS_IS_APPLICATION (self));
+  self->use_count++;
+}
+
+
+void
+photos_application_release (PhotosApplication *self)
+{
+  g_return_if_fail (PHOTOS_IS_APPLICATION (self));
+  g_return_if_fail (self->use_count > 0);
+
+  self->use_count--;
+  if (self->main_window_deleted && self->use_count == 0)
+    gtk_widget_destroy (self->main_window);
+}
