@@ -256,6 +256,7 @@ photos_export_notification_constructed (GObject *object)
 
   label = gtk_label_new (msg);
   gtk_widget_set_halign (label, GTK_ALIGN_START);
+  gtk_widget_set_hexpand (label, TRUE);
   gtk_container_add (GTK_CONTAINER (self), label);
   g_free (msg);
 
@@ -325,11 +326,7 @@ photos_export_notification_constructed (GObject *object)
   photos_notification_manager_add_notification (PHOTOS_NOTIFICATION_MANAGER (self->ntfctn_mngr),
                                                 GTK_WIDGET (self));
 
-  self->timeout_id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT,
-                                                 EXPORT_TIMEOUT,
-                                                 photos_export_notification_timeout,
-                                                 g_object_ref (self),
-                                                 g_object_unref);
+  self->timeout_id = g_timeout_add_seconds (EXPORT_TIMEOUT, photos_export_notification_timeout, self);
 }
 
 
@@ -338,6 +335,8 @@ photos_export_notification_dispose (GObject *object)
 {
   PhotosExportNotification *self = PHOTOS_EXPORT_NOTIFICATION (object);
 
+  photos_export_notification_remove_timeout (self);
+
   if (self->items != NULL)
     {
       g_list_free_full (self->items, g_object_unref);
@@ -396,7 +395,7 @@ photos_export_notification_set_property (GObject *object, guint prop_id, const G
 static void
 photos_export_notification_init (PhotosExportNotification *self)
 {
-  self->ntfctn_mngr = g_object_ref_sink (photos_notification_manager_dup_singleton ());
+  self->ntfctn_mngr = photos_notification_manager_dup_singleton ();
 }
 
 
