@@ -35,6 +35,7 @@
 
 struct _PhotosOffsetControllerPrivate
 {
+  GCancellable *cancellable;
   PhotosTrackerQueue *queue;
   gint count;
   gint offset;
@@ -62,20 +63,36 @@ enum
 static void
 photos_offset_controller_cursor_next (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-  PhotosOffsetController *self = PHOTOS_OFFSET_CONTROLLER (user_data);
-  PhotosOffsetControllerPrivate *priv = self->priv;
+  PhotosOffsetController *self;
+  PhotosOffsetControllerPrivate *priv;
+  GError *error;
   TrackerSparqlCursor *cursor = TRACKER_SPARQL_CURSOR (source_object);
-  gboolean valid;
+  gboolean success;
 
-  valid = tracker_sparql_cursor_next_finish (cursor, res, NULL);
-  if (valid)
+  error = NULL;
+  /* Note that tracker_sparql_cursor_next_finish can return FALSE even without
+   * an error
+   */
+  success = tracker_sparql_cursor_next_finish (cursor, res, &error);
+  if (error != NULL)
+    {
+      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        g_warning ("Unable to query the item count: %s", error->message);
+      g_error_free (error);
+      goto out;
+    }
+
+  self = PHOTOS_OFFSET_CONTROLLER (user_data);
+  priv = photos_offset_controller_get_instance_private (self);
+
+  if (success)
     {
       priv->count = (gint) tracker_sparql_cursor_get_integer (cursor, 0);
       g_signal_emit (self, signals[COUNT_CHANGED], 0, priv->count);
     }
 
+ out:
   tracker_sparql_cursor_close (cursor);
-  g_object_unref (self);
 }
 
 
@@ -83,10 +100,13 @@ static void
 photos_offset_controller_reset_count_query_executed (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
   PhotosOffsetController *self = PHOTOS_OFFSET_CONTROLLER (user_data);
+  PhotosOffsetControllerPrivate *priv;
   TrackerSparqlConnection *connection = TRACKER_SPARQL_CONNECTION (source_object);
   TrackerSparqlCursor *cursor;
   GError *error;
 
+  priv = photos_offset_controller_get_instance_private (self);
+
   error = NULL;
   cursor = tracker_sparql_connection_query_finish (connection, res, &error);
   if (error != NULL)
@@ -95,7 +115,10 @@ photos_offset_controller_reset_count_query_executed (GObject *source_object, GAs
       return;
     }
 
-  tracker_sparql_cursor_next_async (cursor, NULL, photos_offset_controller_cursor_next, g_object_ref (self));
+  tracker_sparql_cursor_next_async (cursor,
+                                    priv->cancellable,
+                                    photos_offset_controller_cursor_next,
+                                    self);
   g_object_unref (cursor);
 }
 
@@ -104,8 +127,17 @@ static void
 photos_offset_controller_dispose (GObject *object)
 {
   PhotosOffsetController *self = PHOTOS_OFFSET_CONTROLLER (object);
+  PhotosOffsetControllerPrivate *priv;
 
-  g_clear_object (&self->priv->queue);
+  priv = photos_offset_controller_get_instance_private (self);
+
+  if (priv->cancellable != NULL)
+    {
+      g_cancellable_cancel (priv->cancellable);
+      g_clear_object (&priv->cancellable);
+    }
+
+  g_clear_object (&priv->queue);
 
   G_OBJECT_CLASS (photos_offset_controller_parent_class)->dispose (object);
 }
@@ -116,9 +148,9 @@ photos_offset_controller_init (PhotosOffsetController *self)
 {
   PhotosOffsetControllerPrivate *priv;
 
-  self->priv = photos_offset_controller_get_instance_private (self);
-  priv = self->priv;
+  priv = photos_offset_controller_get_instance_private (self);
 
+  priv->cancellable = g_cancellable_new ();
   priv->queue = photos_tracker_queue_dup_singleton (NULL, NULL);
 }
 
@@ -166,21 +198,29 @@ photos_offset_controller_new (void)
 gint
 photos_offset_controller_get_count (PhotosOffsetController *self)
 {
-  return self->priv->count;
+  PhotosOffsetControllerPrivate *priv;
+
+  priv = photos_offset_controller_get_instance_private (self);
+  return priv->count;
 }
 
 
 gint
 photos_offset_controller_get_offset (PhotosOffsetController *self)
 {
-  return self->priv->offset;
+  PhotosOffsetControllerPrivate *priv;
+
+  priv = photos_offset_controller_get_instance_private (self);
+  return priv->offset;
 }
 
 
 gint
 photos_offset_controller_get_remaining (PhotosOffsetController *self)
 {
-  PhotosOffsetControllerPrivate *priv = self->priv;
+  PhotosOffsetControllerPrivate *priv;
+
+  priv = photos_offset_controller_get_instance_private (self);
   return priv->count - (priv->offset + OFFSET_STEP);
 }
 
@@ -195,9 +235,11 @@ photos_offset_controller_get_step (PhotosOffsetController *self)
 void
 photos_offset_controller_increase_offset (PhotosOffsetController *self)
 {
-  PhotosOffsetControllerPrivate *priv = self->priv;
+  PhotosOffsetControllerPrivate *priv;
   gint remaining;
 
+  priv = photos_offset_controller_get_instance_private (self);
+
   remaining = photos_offset_controller_get_remaining (self);
   if (remaining <= 0)
     return;
@@ -210,9 +252,11 @@ photos_offset_controller_increase_offset (PhotosOffsetController *self)
 void
 photos_offset_controller_reset_count (PhotosOffsetController *self)
 {
-  PhotosOffsetControllerPrivate *priv = self->priv;
+  PhotosOffsetControllerPrivate *priv;
   PhotosQuery *query;
 
+  priv = photos_offset_controller_get_instance_private (self);
+
   if (G_UNLIKELY (priv->queue == NULL))
     return;
 
@@ -232,5 +276,8 @@ photos_offset_controller_reset_count (PhotosOffsetController *self)
 void
 photos_offset_controller_reset_offset (PhotosOffsetController *self)
 {
-  self->priv->offset = 0;
+  PhotosOffsetControllerPrivate *priv;
+
+  priv = photos_offset_controller_get_instance_private (self);
+  priv->offset = 0;
 }
