@@ -43,12 +43,13 @@
 
 struct _PhotosOrganizeCollectionViewPrivate
 {
+  GCancellable *cancellable;
   GtkCellRenderer *renderer_check;
   GtkCellRenderer *renderer_detail;
   GtkCellRenderer *renderer_text;
   GtkListStore *model;
   GtkTreeViewColumn *view_col;
-  PhotosBaseManager *item_mngr;
+  PhotosBaseManager *col_mngr;
   PhotosBaseManager *src_mngr;
   gboolean choice_confirmed;
 };
@@ -112,13 +113,35 @@ photos_organize_collection_view_check_toggled (PhotosOrganizeCollectionView *sel
 
 
 static void
-photos_organize_collection_view_create_collection_executed (const gchar *created_urn, gpointer user_data)
+photos_organize_collection_view_create_collection_executed (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-  PhotosOrganizeCollectionView *self = PHOTOS_ORGANIZE_COLLECTION_VIEW (user_data);
-  PhotosOrganizeCollectionViewPrivate *priv = self->priv;
+  PhotosOrganizeCollectionView *self;
+  PhotosOrganizeCollectionViewPrivate *priv;
+  PhotosCreateCollectionJob *col_job = PHOTOS_CREATE_COLLECTION_JOB (source_object);
+  PhotosSetCollectionJob *set_job = NULL;
+  GError *error;
   GtkTreeIter iter;
   GtkTreePath *path = NULL;
-  PhotosSetCollectionJob *job = NULL;
+  const gchar *created_urn;
+
+  error = NULL;
+  created_urn = photos_create_collection_job_finish (col_job, res, &error);
+  if (error != NULL)
+    {
+      if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        {
+          g_error_free (error);
+          goto out;
+        }
+      else
+        {
+          g_warning ("Unable to create collection: %s", error->message);
+          g_error_free (error);
+        }
+    }
+
+  self = PHOTOS_ORGANIZE_COLLECTION_VIEW (user_data);
+  priv = self->priv;
 
   if (created_urn == NULL)
     {
@@ -133,13 +156,12 @@ photos_organize_collection_view_create_collection_executed (const gchar *created
   gtk_tree_model_get_iter (GTK_TREE_MODEL (priv->model), &iter, path);
   gtk_list_store_set (priv->model, &iter, PHOTOS_ORGANIZE_MODEL_ID, created_urn, -1);
 
-  job = photos_set_collection_job_new (created_urn, TRUE);
-  photos_set_collection_job_run (job, NULL, NULL);
+  set_job = photos_set_collection_job_new (created_urn, TRUE);
+  photos_set_collection_job_run (set_job, NULL, NULL);
 
  out:
-  g_clear_object (&job);
+  g_clear_object (&set_job);
   gtk_tree_path_free (path);
-  g_object_unref (self);
 }
 
 
@@ -153,26 +175,28 @@ photos_organize_collection_view_detail_cell (GtkTreeViewColumn *tree_column,
   PhotosOrganizeCollectionView *self = PHOTOS_ORGANIZE_COLLECTION_VIEW (user_data);
   PhotosOrganizeCollectionViewPrivate *priv = self->priv;
   GObject *object;
-  const gchar *identifier = NULL;
   gchar *id;
 
   gtk_tree_model_get (GTK_TREE_MODEL (priv->model), iter, PHOTOS_ORGANIZE_MODEL_ID, &id, -1);
-  object = photos_base_manager_get_object_by_id (priv->item_mngr, id);
+  object = photos_base_manager_get_object_by_id (priv->col_mngr, id);
 
   if (object != NULL)
-    identifier = photos_base_item_get_identifier (PHOTOS_BASE_ITEM (object));
-
-  if (identifier != NULL && !g_str_has_prefix (identifier, PHOTOS_QUERY_LOCAL_COLLECTIONS_IDENTIFIER))
     {
-      PhotosSource *source;
-      const gchar *name;
-      const gchar *resource_urn;
+      const gchar *identifier;
 
-      resource_urn = photos_base_item_get_resource_urn (PHOTOS_BASE_ITEM (object));
-      source = PHOTOS_SOURCE (photos_base_manager_get_object_by_id (priv->src_mngr, resource_urn));
-      name = photos_source_get_name (source);
-      g_object_set (cell_renderer, "text", name, NULL);
-      gtk_cell_renderer_set_visible (cell_renderer, TRUE);
+      identifier = photos_base_item_get_identifier (PHOTOS_BASE_ITEM (object));
+      if (identifier != NULL && !g_str_has_prefix (identifier, PHOTOS_QUERY_LOCAL_COLLECTIONS_IDENTIFIER))
+        {
+          PhotosSource *source;
+          const gchar *name;
+          const gchar *resource_urn;
+
+          resource_urn = photos_base_item_get_resource_urn (PHOTOS_BASE_ITEM (object));
+          source = PHOTOS_SOURCE (photos_base_manager_get_object_by_id (priv->src_mngr, resource_urn));
+          name = photos_source_get_name (source);
+          g_object_set (cell_renderer, "text", name, NULL);
+          gtk_cell_renderer_set_visible (cell_renderer, TRUE);
+        }
     }
   else
     {
@@ -208,8 +232,9 @@ photos_organize_collection_view_text_edited_real (PhotosOrganizeCollectionView *
 
   job = photos_create_collection_job_new (new_text);
   photos_create_collection_job_run (job,
+                                    priv->cancellable,
                                     photos_organize_collection_view_create_collection_executed,
-                                    g_object_ref (self));
+                                    self);
   g_object_unref (job);
 }
 
@@ -273,8 +298,14 @@ photos_organize_collection_view_dispose (GObject *object)
   PhotosOrganizeCollectionView *self = PHOTOS_ORGANIZE_COLLECTION_VIEW (object);
   PhotosOrganizeCollectionViewPrivate *priv = self->priv;
 
+  if (priv->cancellable != NULL)
+    {
+      g_cancellable_cancel (priv->cancellable);
+      g_clear_object (&priv->cancellable);
+    }
+
   g_clear_object (&priv->model);
-  g_clear_object (&priv->item_mngr);
+  g_clear_object (&priv->col_mngr);
   g_clear_object (&priv->src_mngr);
 
   G_OBJECT_CLASS (photos_organize_collection_view_parent_class)->dispose (object);
@@ -294,6 +325,8 @@ photos_organize_collection_view_init (PhotosOrganizeCollectionView *self)
   app = g_application_get_default ();
   state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
 
+  priv->cancellable = g_cancellable_new ();
+
   priv->model = photos_organize_collection_model_new ();
   gtk_tree_view_set_model (GTK_TREE_VIEW (self), GTK_TREE_MODEL (priv->model));
 
@@ -334,7 +367,7 @@ photos_organize_collection_view_init (PhotosOrganizeCollectionView *self)
                                            self,
                                            NULL);
 
-  priv->item_mngr = g_object_ref (state->item_mngr);
+  priv->col_mngr = g_object_ref (state->src_mngr);
   priv->src_mngr = g_object_ref (state->src_mngr);
 
   gtk_widget_show (GTK_WIDGET (self));
