@@ -105,17 +105,35 @@ photos_properties_dialog_get_camera (GObject *source_object, GAsyncResult *res,
 }
 
 
+static void
+photos_properties_dialog_name_update (PhotosPropertiesDialog *self)
+{
+  const gchar *new_title;
+
+  new_title = gtk_entry_get_text (GTK_ENTRY (self->title_entry));
+  photos_utils_set_edited_name (self->urn, new_title);
+}
+
+
+static void
+photos_properties_dialog_remove_timeout (PhotosPropertiesDialog *self)
+{
+  if (self->title_entry_timeout != 0)
+    {
+      g_source_remove (self->title_entry_timeout);
+      self->title_entry_timeout = 0;
+    }
+}
+
+
 static gboolean
 photos_properties_dialog_title_entry_timeout (gpointer user_data)
 {
   PhotosPropertiesDialog *self = PHOTOS_PROPERTIES_DIALOG (user_data);
-  const gchar *new_title;
 
   self->title_entry_timeout = 0;
-  new_title = gtk_entry_get_text (GTK_ENTRY (self->title_entry));
-  photos_utils_set_edited_name (self->urn, new_title);
+  photos_properties_dialog_name_update (self);
 
-  g_object_unref (self);
   return G_SOURCE_REMOVE;
 }
 
@@ -125,15 +143,11 @@ photos_properties_dialog_title_entry_changed (GtkEditable *editable, gpointer us
 {
   PhotosPropertiesDialog *self = PHOTOS_PROPERTIES_DIALOG (user_data);
 
-  if (self->title_entry_timeout != 0)
-    {
-      g_source_remove (self->title_entry_timeout);
-      self->title_entry_timeout = 0;
-    }
+  photos_properties_dialog_remove_timeout (self);
 
   self->title_entry_timeout = g_timeout_add (TITLE_ENTRY_TIMEOUT,
                                              photos_properties_dialog_title_entry_timeout,
-                                             g_object_ref (self));
+                                             self);
 }
 
 
@@ -508,6 +522,12 @@ photos_properties_dialog_dispose (GObject *object)
 {
   PhotosPropertiesDialog *self = PHOTOS_PROPERTIES_DIALOG (object);
 
+  /* Make sure we save the new entered name before destroying the dialog */
+  if (self->title_entry_timeout != 0)
+    photos_properties_dialog_name_update (self);
+
+  photos_properties_dialog_remove_timeout (self);
+
   if (self->cancellable != NULL)
     {
       g_cancellable_cancel (self->cancellable);
@@ -528,9 +548,6 @@ photos_properties_dialog_finalize (GObject *object)
 
   g_free (self->urn);
 
-  if (self->title_entry_timeout != 0)
-    g_source_remove (self->title_entry_timeout);
-
   G_OBJECT_CLASS (photos_properties_dialog_parent_class)->finalize (object);
 }
 
